# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connect_master.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import connect_pb2 as connect__pb2
from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='connect_master.proto',
  package='connect_master',
  syntax='proto3',
  serialized_options=_b('\n!com.supremainc.sdk.connect_masterP\001Z\035biostar/service/connectMaster'),
  serialized_pb=_b('\n\x14\x63onnect_master.proto\x12\x0e\x63onnect_master\x1a\rconnect.proto\x1a\terr.proto\"N\n\x0e\x43onnectRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12)\n\x0b\x63onnectInfo\x18\x02 \x01(\x0b\x32\x14.connect.ConnectInfo\"#\n\x0f\x43onnectResponse\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"_\n\x19\x41\x64\x64\x41syncConnectionRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12/\n\x0c\x63onnectInfos\x18\x02 \x03(\x0b\x32\x19.connect.AsyncConnectInfo\"\x1c\n\x1a\x41\x64\x64\x41syncConnectionResponse\"D\n\x1c\x44\x65leteAsyncConnectionRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tdeviceIDs\x18\x02 \x03(\r\"\x1f\n\x1d\x44\x65leteAsyncConnectionResponse\"a\n\x1b\x41\x64\x64\x41syncConnectionDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12/\n\x0c\x63onnectInfos\x18\x02 \x03(\x0b\x32\x19.connect.AsyncConnectInfo\"\x1e\n\x1c\x41\x64\x64\x41syncConnectionDBResponse\"F\n\x1e\x44\x65leteAsyncConnectionDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tdeviceIDs\x18\x02 \x03(\r\"!\n\x1f\x44\x65leteAsyncConnectionDBResponse\"0\n\x1bGetAsyncConnectionDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"O\n\x1cGetAsyncConnectionDBResponse\x12/\n\x0c\x63onnectInfos\x18\x01 \x03(\x0b\x32\x19.connect.AsyncConnectInfo\"R\n\x16SetAcceptFilterRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12%\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x15.connect.AcceptFilter\"\x19\n\x17SetAcceptFilterResponse\"+\n\x16GetAcceptFilterRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"@\n\x17GetAcceptFilterResponse\x12%\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x15.connect.AcceptFilter\"T\n\x18SetAcceptFilterDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12%\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x15.connect.AcceptFilter\"\x1b\n\x19SetAcceptFilterDBResponse\"-\n\x18GetAcceptFilterDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"B\n\x19GetAcceptFilterDBResponse\x12%\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x15.connect.AcceptFilter\"*\n\x15GetPendingListRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"I\n\x16GetPendingListResponse\x12/\n\x0b\x64\x65viceInfos\x18\x01 \x03(\x0b\x32\x1a.connect.PendingDeviceInfo\")\n\x14GetDeviceListRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"A\n\x15GetDeviceListResponse\x12(\n\x0b\x64\x65viceInfos\x18\x01 \x03(\x0b\x32\x13.connect.DeviceInfo\"&\n\x11\x44isconnectRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"\x14\n\x12\x44isconnectResponse\")\n\x14\x44isconnectAllRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"\x17\n\x15\x44isconnectAllResponse\"9\n\x13SearchDeviceRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\r\"F\n\x14SearchDeviceResponse\x12.\n\x0b\x64\x65viceInfos\x18\x01 \x03(\x0b\x32\x19.connect.SearchDeviceInfo\"*\n\x15GetSlaveDeviceRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"L\n\x16GetSlaveDeviceResponse\x12\x32\n\x10slaveDeviceInfos\x18\x01 \x03(\x0b\x32\x18.connect.SlaveDeviceInfo\"^\n\x15SetSlaveDeviceRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x32\n\x10slaveDeviceInfos\x18\x02 \x03(\x0b\x32\x18.connect.SlaveDeviceInfo\"\x18\n\x16SetSlaveDeviceResponse\"`\n\x17\x41\x64\x64SlaveDeviceDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x32\n\x10slaveDeviceInfos\x18\x02 \x03(\x0b\x32\x18.connect.SlaveDeviceInfo\"\x1a\n\x18\x41\x64\x64SlaveDeviceDBResponse\"B\n\x1a\x44\x65leteSlaveDeviceDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tdeviceIDs\x18\x02 \x03(\r\"\x1d\n\x1b\x44\x65leteSlaveDeviceDBResponse\",\n\x17GetSlaveDeviceDBRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\"N\n\x18GetSlaveDeviceDBResponse\x12\x32\n\x10slaveDeviceInfos\x18\x01 \x03(\x0b\x32\x18.connect.SlaveDeviceInfo\"+\n\x16SubscribeStatusRequest\x12\x11\n\tqueueSize\x18\x01 \x01(\x05\"]\n\x18SetConnectionModeRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12/\n\x0e\x63onnectionMode\x18\x02 \x01(\x0e\x32\x17.connect.ConnectionMode\"\x1b\n\x19SetConnectionModeResponse\"c\n\x1dSetConnectionModeMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12/\n\x0e\x63onnectionMode\x18\x02 \x01(\x0e\x32\x17.connect.ConnectionMode\"J\n\x1eSetConnectionModeMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x10\x45nableSSLRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x45nableSSLResponse\"*\n\x15\x45nableSSLMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"B\n\x16\x45nableSSLMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"%\n\x11\x44isableSSLRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x14\n\x12\x44isableSSLResponse\"+\n\x16\x44isableSSLMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"C\n\x17\x44isableSSLMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse2\xac\x15\n\rConnectMaster\x12J\n\x07\x43onnect\x12\x1e.connect_master.ConnectRequest\x1a\x1f.connect_master.ConnectResponse\x12k\n\x12\x41\x64\x64\x41syncConnection\x12).connect_master.AddAsyncConnectionRequest\x1a*.connect_master.AddAsyncConnectionResponse\x12t\n\x15\x44\x65leteAsyncConnection\x12,.connect_master.DeleteAsyncConnectionRequest\x1a-.connect_master.DeleteAsyncConnectionResponse\x12q\n\x14\x41\x64\x64\x41syncConnectionDB\x12+.connect_master.AddAsyncConnectionDBRequest\x1a,.connect_master.AddAsyncConnectionDBResponse\x12z\n\x17\x44\x65leteAsyncConnectionDB\x12..connect_master.DeleteAsyncConnectionDBRequest\x1a/.connect_master.DeleteAsyncConnectionDBResponse\x12q\n\x14GetAsyncConnectionDB\x12+.connect_master.GetAsyncConnectionDBRequest\x1a,.connect_master.GetAsyncConnectionDBResponse\x12\x62\n\x0fSetAcceptFilter\x12&.connect_master.SetAcceptFilterRequest\x1a\'.connect_master.SetAcceptFilterResponse\x12\x62\n\x0fGetAcceptFilter\x12&.connect_master.GetAcceptFilterRequest\x1a\'.connect_master.GetAcceptFilterResponse\x12h\n\x11SetAcceptFilterDB\x12(.connect_master.SetAcceptFilterDBRequest\x1a).connect_master.SetAcceptFilterDBResponse\x12h\n\x11GetAcceptFilterDB\x12(.connect_master.GetAcceptFilterDBRequest\x1a).connect_master.GetAcceptFilterDBResponse\x12_\n\x0eGetPendingList\x12%.connect_master.GetPendingListRequest\x1a&.connect_master.GetPendingListResponse\x12\\\n\rGetDeviceList\x12$.connect_master.GetDeviceListRequest\x1a%.connect_master.GetDeviceListResponse\x12S\n\nDisconnect\x12!.connect_master.DisconnectRequest\x1a\".connect_master.DisconnectResponse\x12\\\n\rDisconnectAll\x12$.connect_master.DisconnectAllRequest\x1a%.connect_master.DisconnectAllResponse\x12Y\n\x0cSearchDevice\x12#.connect_master.SearchDeviceRequest\x1a$.connect_master.SearchDeviceResponse\x12_\n\x0eGetSlaveDevice\x12%.connect_master.GetSlaveDeviceRequest\x1a&.connect_master.GetSlaveDeviceResponse\x12_\n\x0eSetSlaveDevice\x12%.connect_master.SetSlaveDeviceRequest\x1a&.connect_master.SetSlaveDeviceResponse\x12\x65\n\x10\x41\x64\x64SlaveDeviceDB\x12\'.connect_master.AddSlaveDeviceDBRequest\x1a(.connect_master.AddSlaveDeviceDBResponse\x12n\n\x13\x44\x65leteSlaveDeviceDB\x12*.connect_master.DeleteSlaveDeviceDBRequest\x1a+.connect_master.DeleteSlaveDeviceDBResponse\x12\x65\n\x10GetSlaveDeviceDB\x12\'.connect_master.GetSlaveDeviceDBRequest\x1a(.connect_master.GetSlaveDeviceDBResponse\x12h\n\x11SetConnectionMode\x12(.connect_master.SetConnectionModeRequest\x1a).connect_master.SetConnectionModeResponse\x12w\n\x16SetConnectionModeMulti\x12-.connect_master.SetConnectionModeMultiRequest\x1a..connect_master.SetConnectionModeMultiResponse\x12P\n\tEnableSSL\x12 .connect_master.EnableSSLRequest\x1a!.connect_master.EnableSSLResponse\x12_\n\x0e\x45nableSSLMulti\x12%.connect_master.EnableSSLMultiRequest\x1a&.connect_master.EnableSSLMultiResponse\x12S\n\nDisableSSL\x12!.connect_master.DisableSSLRequest\x1a\".connect_master.DisableSSLResponse\x12\x62\n\x0f\x44isableSSLMulti\x12&.connect_master.DisableSSLMultiRequest\x1a\'.connect_master.DisableSSLMultiResponse\x12R\n\x0fSubscribeStatus\x12&.connect_master.SubscribeStatusRequest\x1a\x15.connect.StatusChange0\x01\x42\x44\n!com.supremainc.sdk.connect_masterP\x01Z\x1d\x62iostar/service/connectMasterb\x06proto3')
  ,
  dependencies=[connect__pb2.DESCRIPTOR,err__pb2.DESCRIPTOR,])




_CONNECTREQUEST = _descriptor.Descriptor(
  name='ConnectRequest',
  full_name='connect_master.ConnectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.ConnectRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectInfo', full_name='connect_master.ConnectRequest.connectInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=144,
)


_CONNECTRESPONSE = _descriptor.Descriptor(
  name='ConnectResponse',
  full_name='connect_master.ConnectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='connect_master.ConnectResponse.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=181,
)


_ADDASYNCCONNECTIONREQUEST = _descriptor.Descriptor(
  name='AddAsyncConnectionRequest',
  full_name='connect_master.AddAsyncConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.AddAsyncConnectionRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectInfos', full_name='connect_master.AddAsyncConnectionRequest.connectInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=278,
)


_ADDASYNCCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='AddAsyncConnectionResponse',
  full_name='connect_master.AddAsyncConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=308,
)


_DELETEASYNCCONNECTIONREQUEST = _descriptor.Descriptor(
  name='DeleteAsyncConnectionRequest',
  full_name='connect_master.DeleteAsyncConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.DeleteAsyncConnectionRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.DeleteAsyncConnectionRequest.deviceIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=378,
)


_DELETEASYNCCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DeleteAsyncConnectionResponse',
  full_name='connect_master.DeleteAsyncConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=411,
)


_ADDASYNCCONNECTIONDBREQUEST = _descriptor.Descriptor(
  name='AddAsyncConnectionDBRequest',
  full_name='connect_master.AddAsyncConnectionDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.AddAsyncConnectionDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectInfos', full_name='connect_master.AddAsyncConnectionDBRequest.connectInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=510,
)


_ADDASYNCCONNECTIONDBRESPONSE = _descriptor.Descriptor(
  name='AddAsyncConnectionDBResponse',
  full_name='connect_master.AddAsyncConnectionDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=542,
)


_DELETEASYNCCONNECTIONDBREQUEST = _descriptor.Descriptor(
  name='DeleteAsyncConnectionDBRequest',
  full_name='connect_master.DeleteAsyncConnectionDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.DeleteAsyncConnectionDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.DeleteAsyncConnectionDBRequest.deviceIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=614,
)


_DELETEASYNCCONNECTIONDBRESPONSE = _descriptor.Descriptor(
  name='DeleteAsyncConnectionDBResponse',
  full_name='connect_master.DeleteAsyncConnectionDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=649,
)


_GETASYNCCONNECTIONDBREQUEST = _descriptor.Descriptor(
  name='GetAsyncConnectionDBRequest',
  full_name='connect_master.GetAsyncConnectionDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetAsyncConnectionDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=699,
)


_GETASYNCCONNECTIONDBRESPONSE = _descriptor.Descriptor(
  name='GetAsyncConnectionDBResponse',
  full_name='connect_master.GetAsyncConnectionDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectInfos', full_name='connect_master.GetAsyncConnectionDBResponse.connectInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=701,
  serialized_end=780,
)


_SETACCEPTFILTERREQUEST = _descriptor.Descriptor(
  name='SetAcceptFilterRequest',
  full_name='connect_master.SetAcceptFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.SetAcceptFilterRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='connect_master.SetAcceptFilterRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=864,
)


_SETACCEPTFILTERRESPONSE = _descriptor.Descriptor(
  name='SetAcceptFilterResponse',
  full_name='connect_master.SetAcceptFilterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=891,
)


_GETACCEPTFILTERREQUEST = _descriptor.Descriptor(
  name='GetAcceptFilterRequest',
  full_name='connect_master.GetAcceptFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetAcceptFilterRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=936,
)


_GETACCEPTFILTERRESPONSE = _descriptor.Descriptor(
  name='GetAcceptFilterResponse',
  full_name='connect_master.GetAcceptFilterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='connect_master.GetAcceptFilterResponse.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1002,
)


_SETACCEPTFILTERDBREQUEST = _descriptor.Descriptor(
  name='SetAcceptFilterDBRequest',
  full_name='connect_master.SetAcceptFilterDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.SetAcceptFilterDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='connect_master.SetAcceptFilterDBRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1088,
)


_SETACCEPTFILTERDBRESPONSE = _descriptor.Descriptor(
  name='SetAcceptFilterDBResponse',
  full_name='connect_master.SetAcceptFilterDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1117,
)


_GETACCEPTFILTERDBREQUEST = _descriptor.Descriptor(
  name='GetAcceptFilterDBRequest',
  full_name='connect_master.GetAcceptFilterDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetAcceptFilterDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1119,
  serialized_end=1164,
)


_GETACCEPTFILTERDBRESPONSE = _descriptor.Descriptor(
  name='GetAcceptFilterDBResponse',
  full_name='connect_master.GetAcceptFilterDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='connect_master.GetAcceptFilterDBResponse.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1166,
  serialized_end=1232,
)


_GETPENDINGLISTREQUEST = _descriptor.Descriptor(
  name='GetPendingListRequest',
  full_name='connect_master.GetPendingListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetPendingListRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1276,
)


_GETPENDINGLISTRESPONSE = _descriptor.Descriptor(
  name='GetPendingListResponse',
  full_name='connect_master.GetPendingListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceInfos', full_name='connect_master.GetPendingListResponse.deviceInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1278,
  serialized_end=1351,
)


_GETDEVICELISTREQUEST = _descriptor.Descriptor(
  name='GetDeviceListRequest',
  full_name='connect_master.GetDeviceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetDeviceListRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1394,
)


_GETDEVICELISTRESPONSE = _descriptor.Descriptor(
  name='GetDeviceListResponse',
  full_name='connect_master.GetDeviceListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceInfos', full_name='connect_master.GetDeviceListResponse.deviceInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1396,
  serialized_end=1461,
)


_DISCONNECTREQUEST = _descriptor.Descriptor(
  name='DisconnectRequest',
  full_name='connect_master.DisconnectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.DisconnectRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1501,
)


_DISCONNECTRESPONSE = _descriptor.Descriptor(
  name='DisconnectResponse',
  full_name='connect_master.DisconnectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1523,
)


_DISCONNECTALLREQUEST = _descriptor.Descriptor(
  name='DisconnectAllRequest',
  full_name='connect_master.DisconnectAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.DisconnectAllRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1525,
  serialized_end=1566,
)


_DISCONNECTALLRESPONSE = _descriptor.Descriptor(
  name='DisconnectAllResponse',
  full_name='connect_master.DisconnectAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1591,
)


_SEARCHDEVICEREQUEST = _descriptor.Descriptor(
  name='SearchDeviceRequest',
  full_name='connect_master.SearchDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.SearchDeviceRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='connect_master.SearchDeviceRequest.timeout', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1593,
  serialized_end=1650,
)


_SEARCHDEVICERESPONSE = _descriptor.Descriptor(
  name='SearchDeviceResponse',
  full_name='connect_master.SearchDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceInfos', full_name='connect_master.SearchDeviceResponse.deviceInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1652,
  serialized_end=1722,
)


_GETSLAVEDEVICEREQUEST = _descriptor.Descriptor(
  name='GetSlaveDeviceRequest',
  full_name='connect_master.GetSlaveDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetSlaveDeviceRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1766,
)


_GETSLAVEDEVICERESPONSE = _descriptor.Descriptor(
  name='GetSlaveDeviceResponse',
  full_name='connect_master.GetSlaveDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveDeviceInfos', full_name='connect_master.GetSlaveDeviceResponse.slaveDeviceInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1844,
)


_SETSLAVEDEVICEREQUEST = _descriptor.Descriptor(
  name='SetSlaveDeviceRequest',
  full_name='connect_master.SetSlaveDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.SetSlaveDeviceRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slaveDeviceInfos', full_name='connect_master.SetSlaveDeviceRequest.slaveDeviceInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=1940,
)


_SETSLAVEDEVICERESPONSE = _descriptor.Descriptor(
  name='SetSlaveDeviceResponse',
  full_name='connect_master.SetSlaveDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1942,
  serialized_end=1966,
)


_ADDSLAVEDEVICEDBREQUEST = _descriptor.Descriptor(
  name='AddSlaveDeviceDBRequest',
  full_name='connect_master.AddSlaveDeviceDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.AddSlaveDeviceDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slaveDeviceInfos', full_name='connect_master.AddSlaveDeviceDBRequest.slaveDeviceInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2064,
)


_ADDSLAVEDEVICEDBRESPONSE = _descriptor.Descriptor(
  name='AddSlaveDeviceDBResponse',
  full_name='connect_master.AddSlaveDeviceDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2066,
  serialized_end=2092,
)


_DELETESLAVEDEVICEDBREQUEST = _descriptor.Descriptor(
  name='DeleteSlaveDeviceDBRequest',
  full_name='connect_master.DeleteSlaveDeviceDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.DeleteSlaveDeviceDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.DeleteSlaveDeviceDBRequest.deviceIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2094,
  serialized_end=2160,
)


_DELETESLAVEDEVICEDBRESPONSE = _descriptor.Descriptor(
  name='DeleteSlaveDeviceDBResponse',
  full_name='connect_master.DeleteSlaveDeviceDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2162,
  serialized_end=2191,
)


_GETSLAVEDEVICEDBREQUEST = _descriptor.Descriptor(
  name='GetSlaveDeviceDBRequest',
  full_name='connect_master.GetSlaveDeviceDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='connect_master.GetSlaveDeviceDBRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2193,
  serialized_end=2237,
)


_GETSLAVEDEVICEDBRESPONSE = _descriptor.Descriptor(
  name='GetSlaveDeviceDBResponse',
  full_name='connect_master.GetSlaveDeviceDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveDeviceInfos', full_name='connect_master.GetSlaveDeviceDBResponse.slaveDeviceInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2239,
  serialized_end=2317,
)


_SUBSCRIBESTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeStatusRequest',
  full_name='connect_master.SubscribeStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueSize', full_name='connect_master.SubscribeStatusRequest.queueSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2319,
  serialized_end=2362,
)


_SETCONNECTIONMODEREQUEST = _descriptor.Descriptor(
  name='SetConnectionModeRequest',
  full_name='connect_master.SetConnectionModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='connect_master.SetConnectionModeRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectionMode', full_name='connect_master.SetConnectionModeRequest.connectionMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2364,
  serialized_end=2457,
)


_SETCONNECTIONMODERESPONSE = _descriptor.Descriptor(
  name='SetConnectionModeResponse',
  full_name='connect_master.SetConnectionModeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2486,
)


_SETCONNECTIONMODEMULTIREQUEST = _descriptor.Descriptor(
  name='SetConnectionModeMultiRequest',
  full_name='connect_master.SetConnectionModeMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.SetConnectionModeMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectionMode', full_name='connect_master.SetConnectionModeMultiRequest.connectionMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2488,
  serialized_end=2587,
)


_SETCONNECTIONMODEMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConnectionModeMultiResponse',
  full_name='connect_master.SetConnectionModeMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='connect_master.SetConnectionModeMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2589,
  serialized_end=2663,
)


_ENABLESSLREQUEST = _descriptor.Descriptor(
  name='EnableSSLRequest',
  full_name='connect_master.EnableSSLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='connect_master.EnableSSLRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2665,
  serialized_end=2701,
)


_ENABLESSLRESPONSE = _descriptor.Descriptor(
  name='EnableSSLResponse',
  full_name='connect_master.EnableSSLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2703,
  serialized_end=2722,
)


_ENABLESSLMULTIREQUEST = _descriptor.Descriptor(
  name='EnableSSLMultiRequest',
  full_name='connect_master.EnableSSLMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.EnableSSLMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2766,
)


_ENABLESSLMULTIRESPONSE = _descriptor.Descriptor(
  name='EnableSSLMultiResponse',
  full_name='connect_master.EnableSSLMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='connect_master.EnableSSLMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2768,
  serialized_end=2834,
)


_DISABLESSLREQUEST = _descriptor.Descriptor(
  name='DisableSSLRequest',
  full_name='connect_master.DisableSSLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='connect_master.DisableSSLRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2836,
  serialized_end=2873,
)


_DISABLESSLRESPONSE = _descriptor.Descriptor(
  name='DisableSSLResponse',
  full_name='connect_master.DisableSSLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2875,
  serialized_end=2895,
)


_DISABLESSLMULTIREQUEST = _descriptor.Descriptor(
  name='DisableSSLMultiRequest',
  full_name='connect_master.DisableSSLMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='connect_master.DisableSSLMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2897,
  serialized_end=2940,
)


_DISABLESSLMULTIRESPONSE = _descriptor.Descriptor(
  name='DisableSSLMultiResponse',
  full_name='connect_master.DisableSSLMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='connect_master.DisableSSLMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2942,
  serialized_end=3009,
)

_CONNECTREQUEST.fields_by_name['connectInfo'].message_type = connect__pb2._CONNECTINFO
_ADDASYNCCONNECTIONREQUEST.fields_by_name['connectInfos'].message_type = connect__pb2._ASYNCCONNECTINFO
_ADDASYNCCONNECTIONDBREQUEST.fields_by_name['connectInfos'].message_type = connect__pb2._ASYNCCONNECTINFO
_GETASYNCCONNECTIONDBRESPONSE.fields_by_name['connectInfos'].message_type = connect__pb2._ASYNCCONNECTINFO
_SETACCEPTFILTERREQUEST.fields_by_name['filter'].message_type = connect__pb2._ACCEPTFILTER
_GETACCEPTFILTERRESPONSE.fields_by_name['filter'].message_type = connect__pb2._ACCEPTFILTER
_SETACCEPTFILTERDBREQUEST.fields_by_name['filter'].message_type = connect__pb2._ACCEPTFILTER
_GETACCEPTFILTERDBRESPONSE.fields_by_name['filter'].message_type = connect__pb2._ACCEPTFILTER
_GETPENDINGLISTRESPONSE.fields_by_name['deviceInfos'].message_type = connect__pb2._PENDINGDEVICEINFO
_GETDEVICELISTRESPONSE.fields_by_name['deviceInfos'].message_type = connect__pb2._DEVICEINFO
_SEARCHDEVICERESPONSE.fields_by_name['deviceInfos'].message_type = connect__pb2._SEARCHDEVICEINFO
_GETSLAVEDEVICERESPONSE.fields_by_name['slaveDeviceInfos'].message_type = connect__pb2._SLAVEDEVICEINFO
_SETSLAVEDEVICEREQUEST.fields_by_name['slaveDeviceInfos'].message_type = connect__pb2._SLAVEDEVICEINFO
_ADDSLAVEDEVICEDBREQUEST.fields_by_name['slaveDeviceInfos'].message_type = connect__pb2._SLAVEDEVICEINFO
_GETSLAVEDEVICEDBRESPONSE.fields_by_name['slaveDeviceInfos'].message_type = connect__pb2._SLAVEDEVICEINFO
_SETCONNECTIONMODEREQUEST.fields_by_name['connectionMode'].enum_type = connect__pb2._CONNECTIONMODE
_SETCONNECTIONMODEMULTIREQUEST.fields_by_name['connectionMode'].enum_type = connect__pb2._CONNECTIONMODE
_SETCONNECTIONMODEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_ENABLESSLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DISABLESSLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['ConnectRequest'] = _CONNECTREQUEST
DESCRIPTOR.message_types_by_name['ConnectResponse'] = _CONNECTRESPONSE
DESCRIPTOR.message_types_by_name['AddAsyncConnectionRequest'] = _ADDASYNCCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['AddAsyncConnectionResponse'] = _ADDASYNCCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAsyncConnectionRequest'] = _DELETEASYNCCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteAsyncConnectionResponse'] = _DELETEASYNCCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AddAsyncConnectionDBRequest'] = _ADDASYNCCONNECTIONDBREQUEST
DESCRIPTOR.message_types_by_name['AddAsyncConnectionDBResponse'] = _ADDASYNCCONNECTIONDBRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAsyncConnectionDBRequest'] = _DELETEASYNCCONNECTIONDBREQUEST
DESCRIPTOR.message_types_by_name['DeleteAsyncConnectionDBResponse'] = _DELETEASYNCCONNECTIONDBRESPONSE
DESCRIPTOR.message_types_by_name['GetAsyncConnectionDBRequest'] = _GETASYNCCONNECTIONDBREQUEST
DESCRIPTOR.message_types_by_name['GetAsyncConnectionDBResponse'] = _GETASYNCCONNECTIONDBRESPONSE
DESCRIPTOR.message_types_by_name['SetAcceptFilterRequest'] = _SETACCEPTFILTERREQUEST
DESCRIPTOR.message_types_by_name['SetAcceptFilterResponse'] = _SETACCEPTFILTERRESPONSE
DESCRIPTOR.message_types_by_name['GetAcceptFilterRequest'] = _GETACCEPTFILTERREQUEST
DESCRIPTOR.message_types_by_name['GetAcceptFilterResponse'] = _GETACCEPTFILTERRESPONSE
DESCRIPTOR.message_types_by_name['SetAcceptFilterDBRequest'] = _SETACCEPTFILTERDBREQUEST
DESCRIPTOR.message_types_by_name['SetAcceptFilterDBResponse'] = _SETACCEPTFILTERDBRESPONSE
DESCRIPTOR.message_types_by_name['GetAcceptFilterDBRequest'] = _GETACCEPTFILTERDBREQUEST
DESCRIPTOR.message_types_by_name['GetAcceptFilterDBResponse'] = _GETACCEPTFILTERDBRESPONSE
DESCRIPTOR.message_types_by_name['GetPendingListRequest'] = _GETPENDINGLISTREQUEST
DESCRIPTOR.message_types_by_name['GetPendingListResponse'] = _GETPENDINGLISTRESPONSE
DESCRIPTOR.message_types_by_name['GetDeviceListRequest'] = _GETDEVICELISTREQUEST
DESCRIPTOR.message_types_by_name['GetDeviceListResponse'] = _GETDEVICELISTRESPONSE
DESCRIPTOR.message_types_by_name['DisconnectRequest'] = _DISCONNECTREQUEST
DESCRIPTOR.message_types_by_name['DisconnectResponse'] = _DISCONNECTRESPONSE
DESCRIPTOR.message_types_by_name['DisconnectAllRequest'] = _DISCONNECTALLREQUEST
DESCRIPTOR.message_types_by_name['DisconnectAllResponse'] = _DISCONNECTALLRESPONSE
DESCRIPTOR.message_types_by_name['SearchDeviceRequest'] = _SEARCHDEVICEREQUEST
DESCRIPTOR.message_types_by_name['SearchDeviceResponse'] = _SEARCHDEVICERESPONSE
DESCRIPTOR.message_types_by_name['GetSlaveDeviceRequest'] = _GETSLAVEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['GetSlaveDeviceResponse'] = _GETSLAVEDEVICERESPONSE
DESCRIPTOR.message_types_by_name['SetSlaveDeviceRequest'] = _SETSLAVEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['SetSlaveDeviceResponse'] = _SETSLAVEDEVICERESPONSE
DESCRIPTOR.message_types_by_name['AddSlaveDeviceDBRequest'] = _ADDSLAVEDEVICEDBREQUEST
DESCRIPTOR.message_types_by_name['AddSlaveDeviceDBResponse'] = _ADDSLAVEDEVICEDBRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSlaveDeviceDBRequest'] = _DELETESLAVEDEVICEDBREQUEST
DESCRIPTOR.message_types_by_name['DeleteSlaveDeviceDBResponse'] = _DELETESLAVEDEVICEDBRESPONSE
DESCRIPTOR.message_types_by_name['GetSlaveDeviceDBRequest'] = _GETSLAVEDEVICEDBREQUEST
DESCRIPTOR.message_types_by_name['GetSlaveDeviceDBResponse'] = _GETSLAVEDEVICEDBRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeStatusRequest'] = _SUBSCRIBESTATUSREQUEST
DESCRIPTOR.message_types_by_name['SetConnectionModeRequest'] = _SETCONNECTIONMODEREQUEST
DESCRIPTOR.message_types_by_name['SetConnectionModeResponse'] = _SETCONNECTIONMODERESPONSE
DESCRIPTOR.message_types_by_name['SetConnectionModeMultiRequest'] = _SETCONNECTIONMODEMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConnectionModeMultiResponse'] = _SETCONNECTIONMODEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['EnableSSLRequest'] = _ENABLESSLREQUEST
DESCRIPTOR.message_types_by_name['EnableSSLResponse'] = _ENABLESSLRESPONSE
DESCRIPTOR.message_types_by_name['EnableSSLMultiRequest'] = _ENABLESSLMULTIREQUEST
DESCRIPTOR.message_types_by_name['EnableSSLMultiResponse'] = _ENABLESSLMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DisableSSLRequest'] = _DISABLESSLREQUEST
DESCRIPTOR.message_types_by_name['DisableSSLResponse'] = _DISABLESSLRESPONSE
DESCRIPTOR.message_types_by_name['DisableSSLMultiRequest'] = _DISABLESSLMULTIREQUEST
DESCRIPTOR.message_types_by_name['DisableSSLMultiResponse'] = _DISABLESSLMULTIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectRequest = _reflection.GeneratedProtocolMessageType('ConnectRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.ConnectRequest)
  ))
_sym_db.RegisterMessage(ConnectRequest)

ConnectResponse = _reflection.GeneratedProtocolMessageType('ConnectResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.ConnectResponse)
  ))
_sym_db.RegisterMessage(ConnectResponse)

AddAsyncConnectionRequest = _reflection.GeneratedProtocolMessageType('AddAsyncConnectionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDASYNCCONNECTIONREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddAsyncConnectionRequest)
  ))
_sym_db.RegisterMessage(AddAsyncConnectionRequest)

AddAsyncConnectionResponse = _reflection.GeneratedProtocolMessageType('AddAsyncConnectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDASYNCCONNECTIONRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddAsyncConnectionResponse)
  ))
_sym_db.RegisterMessage(AddAsyncConnectionResponse)

DeleteAsyncConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteAsyncConnectionRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEASYNCCONNECTIONREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteAsyncConnectionRequest)
  ))
_sym_db.RegisterMessage(DeleteAsyncConnectionRequest)

DeleteAsyncConnectionResponse = _reflection.GeneratedProtocolMessageType('DeleteAsyncConnectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEASYNCCONNECTIONRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteAsyncConnectionResponse)
  ))
_sym_db.RegisterMessage(DeleteAsyncConnectionResponse)

AddAsyncConnectionDBRequest = _reflection.GeneratedProtocolMessageType('AddAsyncConnectionDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDASYNCCONNECTIONDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddAsyncConnectionDBRequest)
  ))
_sym_db.RegisterMessage(AddAsyncConnectionDBRequest)

AddAsyncConnectionDBResponse = _reflection.GeneratedProtocolMessageType('AddAsyncConnectionDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDASYNCCONNECTIONDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddAsyncConnectionDBResponse)
  ))
_sym_db.RegisterMessage(AddAsyncConnectionDBResponse)

DeleteAsyncConnectionDBRequest = _reflection.GeneratedProtocolMessageType('DeleteAsyncConnectionDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEASYNCCONNECTIONDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteAsyncConnectionDBRequest)
  ))
_sym_db.RegisterMessage(DeleteAsyncConnectionDBRequest)

DeleteAsyncConnectionDBResponse = _reflection.GeneratedProtocolMessageType('DeleteAsyncConnectionDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEASYNCCONNECTIONDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteAsyncConnectionDBResponse)
  ))
_sym_db.RegisterMessage(DeleteAsyncConnectionDBResponse)

GetAsyncConnectionDBRequest = _reflection.GeneratedProtocolMessageType('GetAsyncConnectionDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETASYNCCONNECTIONDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAsyncConnectionDBRequest)
  ))
_sym_db.RegisterMessage(GetAsyncConnectionDBRequest)

GetAsyncConnectionDBResponse = _reflection.GeneratedProtocolMessageType('GetAsyncConnectionDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETASYNCCONNECTIONDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAsyncConnectionDBResponse)
  ))
_sym_db.RegisterMessage(GetAsyncConnectionDBResponse)

SetAcceptFilterRequest = _reflection.GeneratedProtocolMessageType('SetAcceptFilterRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETACCEPTFILTERREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetAcceptFilterRequest)
  ))
_sym_db.RegisterMessage(SetAcceptFilterRequest)

SetAcceptFilterResponse = _reflection.GeneratedProtocolMessageType('SetAcceptFilterResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETACCEPTFILTERRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetAcceptFilterResponse)
  ))
_sym_db.RegisterMessage(SetAcceptFilterResponse)

GetAcceptFilterRequest = _reflection.GeneratedProtocolMessageType('GetAcceptFilterRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCEPTFILTERREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAcceptFilterRequest)
  ))
_sym_db.RegisterMessage(GetAcceptFilterRequest)

GetAcceptFilterResponse = _reflection.GeneratedProtocolMessageType('GetAcceptFilterResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETACCEPTFILTERRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAcceptFilterResponse)
  ))
_sym_db.RegisterMessage(GetAcceptFilterResponse)

SetAcceptFilterDBRequest = _reflection.GeneratedProtocolMessageType('SetAcceptFilterDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETACCEPTFILTERDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetAcceptFilterDBRequest)
  ))
_sym_db.RegisterMessage(SetAcceptFilterDBRequest)

SetAcceptFilterDBResponse = _reflection.GeneratedProtocolMessageType('SetAcceptFilterDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETACCEPTFILTERDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetAcceptFilterDBResponse)
  ))
_sym_db.RegisterMessage(SetAcceptFilterDBResponse)

GetAcceptFilterDBRequest = _reflection.GeneratedProtocolMessageType('GetAcceptFilterDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCEPTFILTERDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAcceptFilterDBRequest)
  ))
_sym_db.RegisterMessage(GetAcceptFilterDBRequest)

GetAcceptFilterDBResponse = _reflection.GeneratedProtocolMessageType('GetAcceptFilterDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETACCEPTFILTERDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetAcceptFilterDBResponse)
  ))
_sym_db.RegisterMessage(GetAcceptFilterDBResponse)

GetPendingListRequest = _reflection.GeneratedProtocolMessageType('GetPendingListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPENDINGLISTREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetPendingListRequest)
  ))
_sym_db.RegisterMessage(GetPendingListRequest)

GetPendingListResponse = _reflection.GeneratedProtocolMessageType('GetPendingListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPENDINGLISTRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetPendingListResponse)
  ))
_sym_db.RegisterMessage(GetPendingListResponse)

GetDeviceListRequest = _reflection.GeneratedProtocolMessageType('GetDeviceListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDEVICELISTREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetDeviceListRequest)
  ))
_sym_db.RegisterMessage(GetDeviceListRequest)

GetDeviceListResponse = _reflection.GeneratedProtocolMessageType('GetDeviceListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDEVICELISTRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetDeviceListResponse)
  ))
_sym_db.RegisterMessage(GetDeviceListResponse)

DisconnectRequest = _reflection.GeneratedProtocolMessageType('DisconnectRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisconnectRequest)
  ))
_sym_db.RegisterMessage(DisconnectRequest)

DisconnectResponse = _reflection.GeneratedProtocolMessageType('DisconnectResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisconnectResponse)
  ))
_sym_db.RegisterMessage(DisconnectResponse)

DisconnectAllRequest = _reflection.GeneratedProtocolMessageType('DisconnectAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTALLREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisconnectAllRequest)
  ))
_sym_db.RegisterMessage(DisconnectAllRequest)

DisconnectAllResponse = _reflection.GeneratedProtocolMessageType('DisconnectAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTALLRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisconnectAllResponse)
  ))
_sym_db.RegisterMessage(DisconnectAllResponse)

SearchDeviceRequest = _reflection.GeneratedProtocolMessageType('SearchDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHDEVICEREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SearchDeviceRequest)
  ))
_sym_db.RegisterMessage(SearchDeviceRequest)

SearchDeviceResponse = _reflection.GeneratedProtocolMessageType('SearchDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHDEVICERESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SearchDeviceResponse)
  ))
_sym_db.RegisterMessage(SearchDeviceResponse)

GetSlaveDeviceRequest = _reflection.GeneratedProtocolMessageType('GetSlaveDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSLAVEDEVICEREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetSlaveDeviceRequest)
  ))
_sym_db.RegisterMessage(GetSlaveDeviceRequest)

GetSlaveDeviceResponse = _reflection.GeneratedProtocolMessageType('GetSlaveDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSLAVEDEVICERESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetSlaveDeviceResponse)
  ))
_sym_db.RegisterMessage(GetSlaveDeviceResponse)

SetSlaveDeviceRequest = _reflection.GeneratedProtocolMessageType('SetSlaveDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSLAVEDEVICEREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetSlaveDeviceRequest)
  ))
_sym_db.RegisterMessage(SetSlaveDeviceRequest)

SetSlaveDeviceResponse = _reflection.GeneratedProtocolMessageType('SetSlaveDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSLAVEDEVICERESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetSlaveDeviceResponse)
  ))
_sym_db.RegisterMessage(SetSlaveDeviceResponse)

AddSlaveDeviceDBRequest = _reflection.GeneratedProtocolMessageType('AddSlaveDeviceDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDSLAVEDEVICEDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddSlaveDeviceDBRequest)
  ))
_sym_db.RegisterMessage(AddSlaveDeviceDBRequest)

AddSlaveDeviceDBResponse = _reflection.GeneratedProtocolMessageType('AddSlaveDeviceDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDSLAVEDEVICEDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.AddSlaveDeviceDBResponse)
  ))
_sym_db.RegisterMessage(AddSlaveDeviceDBResponse)

DeleteSlaveDeviceDBRequest = _reflection.GeneratedProtocolMessageType('DeleteSlaveDeviceDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETESLAVEDEVICEDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteSlaveDeviceDBRequest)
  ))
_sym_db.RegisterMessage(DeleteSlaveDeviceDBRequest)

DeleteSlaveDeviceDBResponse = _reflection.GeneratedProtocolMessageType('DeleteSlaveDeviceDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETESLAVEDEVICEDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DeleteSlaveDeviceDBResponse)
  ))
_sym_db.RegisterMessage(DeleteSlaveDeviceDBResponse)

GetSlaveDeviceDBRequest = _reflection.GeneratedProtocolMessageType('GetSlaveDeviceDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSLAVEDEVICEDBREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetSlaveDeviceDBRequest)
  ))
_sym_db.RegisterMessage(GetSlaveDeviceDBRequest)

GetSlaveDeviceDBResponse = _reflection.GeneratedProtocolMessageType('GetSlaveDeviceDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSLAVEDEVICEDBRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.GetSlaveDeviceDBResponse)
  ))
_sym_db.RegisterMessage(GetSlaveDeviceDBResponse)

SubscribeStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESTATUSREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SubscribeStatusRequest)
  ))
_sym_db.RegisterMessage(SubscribeStatusRequest)

SetConnectionModeRequest = _reflection.GeneratedProtocolMessageType('SetConnectionModeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONNECTIONMODEREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetConnectionModeRequest)
  ))
_sym_db.RegisterMessage(SetConnectionModeRequest)

SetConnectionModeResponse = _reflection.GeneratedProtocolMessageType('SetConnectionModeResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONNECTIONMODERESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetConnectionModeResponse)
  ))
_sym_db.RegisterMessage(SetConnectionModeResponse)

SetConnectionModeMultiRequest = _reflection.GeneratedProtocolMessageType('SetConnectionModeMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONNECTIONMODEMULTIREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetConnectionModeMultiRequest)
  ))
_sym_db.RegisterMessage(SetConnectionModeMultiRequest)

SetConnectionModeMultiResponse = _reflection.GeneratedProtocolMessageType('SetConnectionModeMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONNECTIONMODEMULTIRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.SetConnectionModeMultiResponse)
  ))
_sym_db.RegisterMessage(SetConnectionModeMultiResponse)

EnableSSLRequest = _reflection.GeneratedProtocolMessageType('EnableSSLRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENABLESSLREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.EnableSSLRequest)
  ))
_sym_db.RegisterMessage(EnableSSLRequest)

EnableSSLResponse = _reflection.GeneratedProtocolMessageType('EnableSSLResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENABLESSLRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.EnableSSLResponse)
  ))
_sym_db.RegisterMessage(EnableSSLResponse)

EnableSSLMultiRequest = _reflection.GeneratedProtocolMessageType('EnableSSLMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENABLESSLMULTIREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.EnableSSLMultiRequest)
  ))
_sym_db.RegisterMessage(EnableSSLMultiRequest)

EnableSSLMultiResponse = _reflection.GeneratedProtocolMessageType('EnableSSLMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENABLESSLMULTIRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.EnableSSLMultiResponse)
  ))
_sym_db.RegisterMessage(EnableSSLMultiResponse)

DisableSSLRequest = _reflection.GeneratedProtocolMessageType('DisableSSLRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISABLESSLREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisableSSLRequest)
  ))
_sym_db.RegisterMessage(DisableSSLRequest)

DisableSSLResponse = _reflection.GeneratedProtocolMessageType('DisableSSLResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISABLESSLRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisableSSLResponse)
  ))
_sym_db.RegisterMessage(DisableSSLResponse)

DisableSSLMultiRequest = _reflection.GeneratedProtocolMessageType('DisableSSLMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISABLESSLMULTIREQUEST,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisableSSLMultiRequest)
  ))
_sym_db.RegisterMessage(DisableSSLMultiRequest)

DisableSSLMultiResponse = _reflection.GeneratedProtocolMessageType('DisableSSLMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISABLESSLMULTIRESPONSE,
  __module__ = 'connect_master_pb2'
  # @@protoc_insertion_point(class_scope:connect_master.DisableSSLMultiResponse)
  ))
_sym_db.RegisterMessage(DisableSSLMultiResponse)


DESCRIPTOR._options = None

_CONNECTMASTER = _descriptor.ServiceDescriptor(
  name='ConnectMaster',
  full_name='connect_master.ConnectMaster',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3012,
  serialized_end=5744,
  methods=[
  _descriptor.MethodDescriptor(
    name='Connect',
    full_name='connect_master.ConnectMaster.Connect',
    index=0,
    containing_service=None,
    input_type=_CONNECTREQUEST,
    output_type=_CONNECTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddAsyncConnection',
    full_name='connect_master.ConnectMaster.AddAsyncConnection',
    index=1,
    containing_service=None,
    input_type=_ADDASYNCCONNECTIONREQUEST,
    output_type=_ADDASYNCCONNECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAsyncConnection',
    full_name='connect_master.ConnectMaster.DeleteAsyncConnection',
    index=2,
    containing_service=None,
    input_type=_DELETEASYNCCONNECTIONREQUEST,
    output_type=_DELETEASYNCCONNECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddAsyncConnectionDB',
    full_name='connect_master.ConnectMaster.AddAsyncConnectionDB',
    index=3,
    containing_service=None,
    input_type=_ADDASYNCCONNECTIONDBREQUEST,
    output_type=_ADDASYNCCONNECTIONDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAsyncConnectionDB',
    full_name='connect_master.ConnectMaster.DeleteAsyncConnectionDB',
    index=4,
    containing_service=None,
    input_type=_DELETEASYNCCONNECTIONDBREQUEST,
    output_type=_DELETEASYNCCONNECTIONDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAsyncConnectionDB',
    full_name='connect_master.ConnectMaster.GetAsyncConnectionDB',
    index=5,
    containing_service=None,
    input_type=_GETASYNCCONNECTIONDBREQUEST,
    output_type=_GETASYNCCONNECTIONDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetAcceptFilter',
    full_name='connect_master.ConnectMaster.SetAcceptFilter',
    index=6,
    containing_service=None,
    input_type=_SETACCEPTFILTERREQUEST,
    output_type=_SETACCEPTFILTERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAcceptFilter',
    full_name='connect_master.ConnectMaster.GetAcceptFilter',
    index=7,
    containing_service=None,
    input_type=_GETACCEPTFILTERREQUEST,
    output_type=_GETACCEPTFILTERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetAcceptFilterDB',
    full_name='connect_master.ConnectMaster.SetAcceptFilterDB',
    index=8,
    containing_service=None,
    input_type=_SETACCEPTFILTERDBREQUEST,
    output_type=_SETACCEPTFILTERDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAcceptFilterDB',
    full_name='connect_master.ConnectMaster.GetAcceptFilterDB',
    index=9,
    containing_service=None,
    input_type=_GETACCEPTFILTERDBREQUEST,
    output_type=_GETACCEPTFILTERDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPendingList',
    full_name='connect_master.ConnectMaster.GetPendingList',
    index=10,
    containing_service=None,
    input_type=_GETPENDINGLISTREQUEST,
    output_type=_GETPENDINGLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceList',
    full_name='connect_master.ConnectMaster.GetDeviceList',
    index=11,
    containing_service=None,
    input_type=_GETDEVICELISTREQUEST,
    output_type=_GETDEVICELISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Disconnect',
    full_name='connect_master.ConnectMaster.Disconnect',
    index=12,
    containing_service=None,
    input_type=_DISCONNECTREQUEST,
    output_type=_DISCONNECTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisconnectAll',
    full_name='connect_master.ConnectMaster.DisconnectAll',
    index=13,
    containing_service=None,
    input_type=_DISCONNECTALLREQUEST,
    output_type=_DISCONNECTALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SearchDevice',
    full_name='connect_master.ConnectMaster.SearchDevice',
    index=14,
    containing_service=None,
    input_type=_SEARCHDEVICEREQUEST,
    output_type=_SEARCHDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveDevice',
    full_name='connect_master.ConnectMaster.GetSlaveDevice',
    index=15,
    containing_service=None,
    input_type=_GETSLAVEDEVICEREQUEST,
    output_type=_GETSLAVEDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSlaveDevice',
    full_name='connect_master.ConnectMaster.SetSlaveDevice',
    index=16,
    containing_service=None,
    input_type=_SETSLAVEDEVICEREQUEST,
    output_type=_SETSLAVEDEVICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddSlaveDeviceDB',
    full_name='connect_master.ConnectMaster.AddSlaveDeviceDB',
    index=17,
    containing_service=None,
    input_type=_ADDSLAVEDEVICEDBREQUEST,
    output_type=_ADDSLAVEDEVICEDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSlaveDeviceDB',
    full_name='connect_master.ConnectMaster.DeleteSlaveDeviceDB',
    index=18,
    containing_service=None,
    input_type=_DELETESLAVEDEVICEDBREQUEST,
    output_type=_DELETESLAVEDEVICEDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveDeviceDB',
    full_name='connect_master.ConnectMaster.GetSlaveDeviceDB',
    index=19,
    containing_service=None,
    input_type=_GETSLAVEDEVICEDBREQUEST,
    output_type=_GETSLAVEDEVICEDBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConnectionMode',
    full_name='connect_master.ConnectMaster.SetConnectionMode',
    index=20,
    containing_service=None,
    input_type=_SETCONNECTIONMODEREQUEST,
    output_type=_SETCONNECTIONMODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConnectionModeMulti',
    full_name='connect_master.ConnectMaster.SetConnectionModeMulti',
    index=21,
    containing_service=None,
    input_type=_SETCONNECTIONMODEMULTIREQUEST,
    output_type=_SETCONNECTIONMODEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EnableSSL',
    full_name='connect_master.ConnectMaster.EnableSSL',
    index=22,
    containing_service=None,
    input_type=_ENABLESSLREQUEST,
    output_type=_ENABLESSLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EnableSSLMulti',
    full_name='connect_master.ConnectMaster.EnableSSLMulti',
    index=23,
    containing_service=None,
    input_type=_ENABLESSLMULTIREQUEST,
    output_type=_ENABLESSLMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisableSSL',
    full_name='connect_master.ConnectMaster.DisableSSL',
    index=24,
    containing_service=None,
    input_type=_DISABLESSLREQUEST,
    output_type=_DISABLESSLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisableSSLMulti',
    full_name='connect_master.ConnectMaster.DisableSSLMulti',
    index=25,
    containing_service=None,
    input_type=_DISABLESSLMULTIREQUEST,
    output_type=_DISABLESSLMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStatus',
    full_name='connect_master.ConnectMaster.SubscribeStatus',
    index=26,
    containing_service=None,
    input_type=_SUBSCRIBESTATUSREQUEST,
    output_type=connect__pb2._STATUSCHANGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONNECTMASTER)

DESCRIPTOR.services_by_name['ConnectMaster'] = _CONNECTMASTER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='admin.proto',
  package='admin',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.adminP\001Z\025biostar/service/admin'),
  serialized_pb=_b('\n\x0b\x61\x64min.proto\x12\x05\x61\x64min\"\x10\n\x0eGetInfoRequest\"5\n\x0fGetInfoResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x11\n\tbuildDate\x18\x02 \x01(\t2A\n\x05\x41\x64min\x12\x38\n\x07GetInfo\x12\x15.admin.GetInfoRequest\x1a\x16.admin.GetInfoResponseB3\n\x18\x63om.supremainc.sdk.adminP\x01Z\x15\x62iostar/service/adminb\x06proto3')
)




_GETINFOREQUEST = _descriptor.Descriptor(
  name='GetInfoRequest',
  full_name='admin.GetInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=38,
)


_GETINFORESPONSE = _descriptor.Descriptor(
  name='GetInfoResponse',
  full_name='admin.GetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='admin.GetInfoResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildDate', full_name='admin.GetInfoResponse.buildDate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=93,
)

DESCRIPTOR.message_types_by_name['GetInfoRequest'] = _GETINFOREQUEST
DESCRIPTOR.message_types_by_name['GetInfoResponse'] = _GETINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInfoRequest = _reflection.GeneratedProtocolMessageType('GetInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINFOREQUEST,
  __module__ = 'admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.GetInfoRequest)
  ))
_sym_db.RegisterMessage(GetInfoRequest)

GetInfoResponse = _reflection.GeneratedProtocolMessageType('GetInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETINFORESPONSE,
  __module__ = 'admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.GetInfoResponse)
  ))
_sym_db.RegisterMessage(GetInfoResponse)


DESCRIPTOR._options = None

_ADMIN = _descriptor.ServiceDescriptor(
  name='Admin',
  full_name='admin.Admin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=95,
  serialized_end=160,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInfo',
    full_name='admin.Admin.GetInfo',
    index=0,
    containing_service=None,
    input_type=_GETINFOREQUEST,
    output_type=_GETINFORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMIN)

DESCRIPTOR.services_by_name['Admin'] = _ADMIN

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import cert_pb2 as cert__pb2


class CertStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateServerCertificate = channel.unary_unary(
        '/cert.Cert/CreateServerCertificate',
        request_serializer=cert__pb2.CreateServerCertificateRequest.SerializeToString,
        response_deserializer=cert__pb2.CreateServerCertificateResponse.FromString,
        )
    self.SetServerCertificate = channel.unary_unary(
        '/cert.Cert/SetServerCertificate',
        request_serializer=cert__pb2.SetServerCertificateRequest.SerializeToString,
        response_deserializer=cert__pb2.SetServerCertificateResponse.FromString,
        )
    self.SetGatewayCertificate = channel.unary_unary(
        '/cert.Cert/SetGatewayCertificate',
        request_serializer=cert__pb2.SetGatewayCertificateRequest.SerializeToString,
        response_deserializer=cert__pb2.SetGatewayCertificateResponse.FromString,
        )


class CertServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateServerCertificate(self, request, context):
    """Server Certificate
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetServerCertificate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetGatewayCertificate(self, request, context):
    """Set Gatweay Certificate: for Device Gateway only
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CertServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateServerCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.CreateServerCertificate,
          request_deserializer=cert__pb2.CreateServerCertificateRequest.FromString,
          response_serializer=cert__pb2.CreateServerCertificateResponse.SerializeToString,
      ),
      'SetServerCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.SetServerCertificate,
          request_deserializer=cert__pb2.SetServerCertificateRequest.FromString,
          response_serializer=cert__pb2.SetServerCertificateResponse.SerializeToString,
      ),
      'SetGatewayCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.SetGatewayCertificate,
          request_deserializer=cert__pb2.SetGatewayCertificateRequest.FromString,
          response_serializer=cert__pb2.SetGatewayCertificateResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'cert.Cert', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
